The build method can be configured using the sass option in rhino.yml:
node: Use Dart Sass
(requires Node.js to be available on the system).
r: Use the {sass} R package.
It is recommended to use Dart Sass which is the primary,
actively developed implementation of Sass.
On systems without Node.js you can use the {sass} R package as a fallback.
It is not advised however, as it uses the deprecated
LibSass implementation.